@@ -999,7 +999,11 @@ def remove_from_os_paths(bindir, usesyspath=True, inmemonly=False):
     os.environ[path_var] = os.environ[path_var].replace(bindir, '')
 
 
-def run_cmd(cmd, cwd=None, logger=None, check=True):
+def run_cmd(cmd, cwd=None, logger=None, check=True, shell=False):
+    """
+    Use shell==True with autotools where new shell is needed to treat the entire command option sequence as a command,
+    e.g., shell=True means running sh -c ./configure CFLAGS="..."
+    """
     local_debug = logger.debug if logger else print
     local_info = logger.info if logger else print
     local_error = logger.error if logger else print
@@ -1008,7 +1012,7 @@ def run_cmd(cmd, cwd=None, logger=None, check=True):
 cwd: {osp.abspath(cwd) if cwd else os.getcwd()}
 """)
     try:
-        proc = subprocess.run(cmd, check=check, shell=False, stdout=subprocess.PIPE, stderr=subprocess.PIPE, cwd=cwd)
+        proc = subprocess.run(cmd, check=check, shell=shell, stdout=subprocess.PIPE, stderr=subprocess.PIPE, cwd=cwd)
         log = proc.stdout.decode(TXT_CODEC)
         local_debug(log)
     except subprocess.CalledProcessError as e:
@@ -1024,7 +1028,7 @@ cwd: {osp.abspath(cwd) if cwd else os.getcwd()}
     return proc
 
 
-def run_daemon(cmd, cwd=None, logger=None, check=True):
+def run_daemon(cmd, cwd=None, logger=None, check=True, shell=False):
     local_debug = logger.debug if logger else print
     local_info = logger.info if logger else print
     local_error = logger.error if logger else print
@@ -1033,7 +1037,7 @@ def run_daemon(cmd, cwd=None, logger=None, check=True):
 cwd: {osp.abspath(cwd) if cwd else os.getcwd()}
 """)
     try:
-        proc = subprocess.Popen(cmd, shell=False, stdout=subprocess.PIPE, stderr=subprocess.PIPE, cwd=cwd)
+        proc = subprocess.Popen(cmd, shell=shell, stdout=subprocess.PIPE, stderr=subprocess.PIPE, cwd=cwd)
         # won't be able to retrieve log from background
     except subprocess.CalledProcessError as e:
         local_info(f'stdout: {e.stdout.decode(TXT_CODEC)}')
@@ -1791,8 +1795,14 @@ class Autotools:
     def autogen(self):
         run_cmd(['./autogen.sh'], cwd=self.pkgRoot, logger=self.logger)
 
-    def configure(self, flags):
-        run_cmd(['./configure'] + flags, cwd=self.pkgRoot, logger=self.logger)
+    def configure(self, opts=(), flags=()):
+        """
+        Must run under shell mode
+        - CFLAGS="...", CXXFLAGS... are not options but environment variables
+        - So must spawn subprocess under shell mode: Treat the ./configure sequence as a whole command
+        """
+        compiler_flags = ['env'] + list(flags) if flags else []
+        run_cmd([' '.join(compiler_flags + ['./configure'] + list(opts))], shell=True, cwd=self.pkgRoot, logger=self.logger)
 
     def make_install(self, njobs=8):
         run_cmd(['make', f'-j{njobs}'], cwd=self.pkgRoot, logger=self.logger)
